@@ -15,19 +15,21 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#define ARROW_VERSION_MAJOR 6
+#define ARROW_VERSION_MAJOR 9
 #define ARROW_VERSION_MINOR 0
-#define ARROW_VERSION_PATCH 1
+#define ARROW_VERSION_PATCH 0
 #define ARROW_VERSION ((ARROW_VERSION_MAJOR * 1000) + ARROW_VERSION_MINOR) * 1000 + ARROW_VERSION_PATCH
 
-#define ARROW_VERSION_STRING "6.0.1"
+#define ARROW_VERSION_STRING "9.0.0"
 
-#define ARROW_SO_VERSION "600"
-#define ARROW_FULL_SO_VERSION "600.1.0"
+#define ARROW_SO_VERSION "900"
+#define ARROW_FULL_SO_VERSION "900.0.0"
 
-#define ARROW_CXX_COMPILER_ID "GNU"
-#define ARROW_CXX_COMPILER_VERSION "11.1.0"
-#define ARROW_CXX_COMPILER_FLAGS "-D_FORTIFY_SOURCE=2 -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fdiagnostics-color=always -O3 -DNDEBUG"
+#define ARROW_CXX_COMPILER_ID "Clang"
+#define ARROW_CXX_COMPILER_VERSION "14.0.6"
+#define ARROW_CXX_COMPILER_FLAGS "-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -Wp,-D_GLIBCXX_ASSERTIONS -flto=auto -Qunused-arguments -fcolor-diagnostics -O3 -DNDEBUG"
+
+#define ARROW_BUILD_TYPE "RELEASE"
 
 #define ARROW_GIT_ID ""
 #define ARROW_GIT_DESCRIPTION ""
@@ -36,13 +38,19 @@
 
 #define ARROW_COMPUTE
 #define ARROW_CSV
+/* #undef ARROW_CUDA */
 #define ARROW_DATASET
 #define ARROW_FILESYSTEM
 #define ARROW_FLIGHT
 #define ARROW_IPC
+#define ARROW_JEMALLOC
+#define ARROW_JEMALLOC_VENDORED
 #define ARROW_JSON
 
+/* #undef ARROW_GCS */
 /* #undef ARROW_S3 */
 #define ARROW_USE_NATIVE_INT128
+/* #undef ARROW_WITH_OPENTELEMETRY */
+/* #undef ARROW_WITH_UCX */
 
 #define GRPCPP_PP_INCLUDE
